package testcase.servlet;
import java.io.*;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.ejb.*;
import testcase.entities.*;
import testcase.interfaces.*;
import java.util.List;
import javax.annotation.PostConstruct;

public class TestServlet extends HttpServlet {

    @EJB
    private TestManager test;
    private boolean injected = false;

    @PostConstruct()
    public void enableTests() {
        injected = true;
    }

    public void doGet (HttpServletRequest req, HttpServletResponse res)
	throws ServletException, IOException
    {
        int mode = 0;
        PrintWriter out = res.getWriter();
        res.setContentType("text/html");

        if (req.getPathInfo() == null) mode = -1;
        else if (req.getPathInfo().equals("/init")) mode = 1;
        else if (req.getPathInfo().equals("/run")) mode = 2;
        else if (req.getPathInfo().equals("/local")) mode = 3;
        else if (req.getPathInfo().equals("/dump")) mode = 4;
	// set content type and other response header fields first

	// then write the data of the response
        out.println("<html>");
        out.println("<head>");
        out.println("<title>Test case</title>");
        out.println("</head>");
        out.println("<body>");
        if (injected) {
            int i=0;
            List<First> firsts;
            List<Second> seconds;
            switch (mode) {
                case 1:
                    out.println("<h1>Setting up entities for test case</h1>");
                    test.createFirst("first entity #1");
                    test.createFirst("first entity #2");
                    test.createFirst("first entity #3");
                    test.createFirst("first entity #4");
                    out.println("<p>Completed successfully</p>");
                    break;
                case 2:
                    out.println("<h1>Running the test case</h1>");
                    test.makeSeconds();
                    out.println("<p>Completed successfully</p>");
                    break;
                case 3:
                    out.println("<h1>Simulating the test case from the servlet</h1>");
                    firsts = test.getFirsts();
                    i = 0;
                    for (First first: firsts) {
                        i++;
                        test.createSecond("made by TestServlet #" + i, first.getData());
                    }
                    out.println("<p>Completed successfully</p>");
                    break;
                case 4:
                    out.println("<h1>Outputting all the entities</h1>");
                    out.println("<p>Here are the Firsts</p>");
                    out.println("<ul>");
                    firsts = test.getFirsts();
                    for (First first: firsts) {
                        out.println("<li>" + first.getData() + "</li>");
                    }
                    out.println("</ul>");
                    out.println("<p>Here are the Seconds</p>");
                    out.println("<ul>");
                    seconds = test.getSeconds();
                    for (Second second: seconds) {
                        out.println("<li>" + second.getName() + " (" + second.getData() + ")</li>");
                    }
                    out.println("</ul>");
                    out.println("<p>Completed successfully</p>");
                    break;
                case -1:
                    out.println("<h1>You should not be here at all</h1>");
                    out.println("<p>Try appending a / to the URL</p>");
                    break;
                default:
                    out.println("<h1>You need to specify the action</h1>");
                    break;
            }
            out.println("<p><a href='init'>Setup the entities for the test</a></p>");
            out.println("<p><a href='run'>Run the test</a></p>");
            out.println("<p><a href='local'>Simulate the test</a></p>");
            out.println("<p><a href='dump'>Output the contents of the databases</a></p>");
        } else {
            out.println("<p>The container does not seem to be injecting a reference to the EJB</p>");
        }
        out.println("</body>");
        out.println("</html>");

	out.close();
    }

    public String getServletInfo() {
        return "A test case servlet";
    }
}

